"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RULE_NAME = void 0;
const experimental_utils_1 = require("@typescript-eslint/experimental-utils");
const utils_1 = require("../utils");
const node_utils_1 = require("../node-utils");
exports.RULE_NAME = 'no-wait-for-empty-callback';
const WAIT_EXPRESSION_QUERY = 'CallExpression[callee.name=/^(waitFor|waitForElementToBeRemoved)$/]';
exports.default = experimental_utils_1.ESLintUtils.RuleCreator(utils_1.getDocsUrl)({
    name: exports.RULE_NAME,
    meta: {
        type: 'suggestion',
        docs: {
            description: "It's preferred to avoid empty callbacks in `waitFor` and `waitForElementToBeRemoved`",
            category: 'Best Practices',
            recommended: 'error',
        },
        messages: {
            noWaitForEmptyCallback: 'Avoid passing empty callback to `{{ methodName }}`. Insert an assertion instead.',
        },
        fixable: null,
        schema: [],
    },
    defaultOptions: [],
    create: function (context) {
        function reportIfEmpty(node) {
            if (node_utils_1.isBlockStatement(node.body) &&
                node.body.body.length === 0 &&
                node_utils_1.isCallExpression(node.parent) &&
                experimental_utils_1.ASTUtils.isIdentifier(node.parent.callee)) {
                context.report({
                    node,
                    loc: node.body.loc.start,
                    messageId: 'noWaitForEmptyCallback',
                    data: {
                        methodName: node.parent.callee.name,
                    },
                });
            }
        }
        function reportNoop(node) {
            context.report({
                node,
                loc: node.loc.start,
                messageId: 'noWaitForEmptyCallback',
            });
        }
        return {
            [`${WAIT_EXPRESSION_QUERY} > ArrowFunctionExpression`]: reportIfEmpty,
            [`${WAIT_EXPRESSION_QUERY} > FunctionExpression`]: reportIfEmpty,
            [`${WAIT_EXPRESSION_QUERY} > Identifier[name="noop"]`]: reportNoop,
        };
    },
});
